@@ -14,10 +14,10 @@ def user_agents(cur):
                     FROM
                         user_agents)
             """
-            
+
     cur.execute(sql)
     return cur.fetchall()
 
 def choose_random(user_agents):
     return choices(population=[ua['user_agent'] for ua in user_agents],
-                    weights=[ua['percent'] for ua in user_agents])
\ No newline at end of file
+                    weights=[ua['percent'] for ua in user_agents])[0]
\ No newline at end of file
